============
Installation
============

At the command line::

    $ pip install murano-pkg-check

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv murano-pkg-check
    $ pip install murano-pkg-check
